@@ -7,6 +7,7 @@ from .confluence_page_checker import ConfluencePageChecker
 from .author_checker import AuthorChecker
 from .case_import_checker import CaseImportChecker
 from .module_display_checker import ModuleDisplayChecker
+from .module_show_checker import ModuleShowChecker
 
 def register(linter):
     linter.register_checker(FunctionCallChecker(linter))
@@ -17,4 +18,4 @@ def register(linter):
     linter.register_checker(ChainedDotFunctionsSyntaxChecker(linter))
     linter.register_checker(AuthorChecker(linter))
     linter.register_checker(CaseImportChecker(linter))
-    linter.register_checker(ModuleDisplayChecker(linter))
+    linter.register_checker(ModuleShowChecker(linter))
